<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>讀取磁盤訊息需要認證</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Run Disk Manager Need Authentication</translation>
		</message>
	</context>
</TS>